package com.example.lecteurdenouvelles.models;

import org.json.JSONObject;

/**
 * @author jub
 *Une nouvelle est caractrise par son identifiant, son titre, son texte, la catgorie  laquelle elle appartient et son image
 */
public class Nouvelle extends JSONReader{
	/**
	 * l'identifiant de la nouvelle
	 */
	private int idnouvelle;
	/**
	 * Le titre de la nouvelle
	 */
	private String titre;
	/**
	 * le texte de la nouvelle
	 */
	private String texte;
	/**
	 * La catgorie d'appartenance de la nouvelle
	 */
	private Categorie categorie;
	/**
	 * L'image de la nouvelle
	 */
	private Image image;
	
	/**
	 * Permet de construire une nouvelle  partir de son identifiant et l'URL http://10.0.2.2/android/main/getNouvelleByIdnouvelle/idnouvelle
	 * @param idnouvelle l'identifiant de la nouvelle
	 */
	public Nouvelle(int idnouvelle){
		super("main/getNouvelleByIdnouvelle/"+idnouvelle);
		parse();
	}
	
	

	/**
	 * Permet de connatre l'identifiant de la nouvelle
	 * @return l'identifiant
	 */
	public int getIdnouvelle() {
		return idnouvelle;
	}

	
	/**
	 * Permet de connatre le titre de la nouvelle
	 * @return le titre de la nouvelle
	 */
	public String getTitre() {
		return titre;
	}

	

	/**
	 * Permet de connatre le texte de la nouvelle
	 * @return le texte de la nouvelle
	 */
	public String getTexte() {
		return texte;
	}

	

	/**
	 * Permet de connatre la catgorie d'appartenance de la nouvelle
	 * @return la catgorie de la nouvelle
	 */
	public Categorie getCategorie() {
		return categorie;
	}


	/**
	 * Permet de connatre l'image de la nouvelle
	 * @return l'image de la nouvelle
	 */
	public Image getImage() {
		return image;
	}

	

	@Override
	public String toString() {
		return "Nouvelle [idnouvelle=" + idnouvelle + ", titre=" + titre
				+ ", texte=" + texte + ", categorie=" + categorie + ", image="
				+ image + "]";
	}

	@Override
	public void parse() {
		String read = read();

		try {
			
			JSONObject jsonObject = new JSONObject(read);
			
			
			
				this.idnouvelle = jsonObject.getInt("idnouvelle");
				this.titre = jsonObject.getString("titre");
				this.texte = jsonObject.getString("texte");
				this.categorie = new Categorie(jsonObject.getJSONObject("categorie").getString("nom"));
				this.image = new Image(jsonObject.getJSONObject("image").getString("url"), jsonObject.getJSONObject("image").getString("description"));
			
			
		} catch (Exception e) {
			e.printStackTrace();
		}
		
	}
}
